'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.search = exports.ERR_INVALID_SORT = exports.ERR_NO_VOCABULARY_SERVICE = exports.ERR_NO_RECORD_SERVICE = exports.SEARCH_REJECTED = exports.SEARCH_FULFILLED = exports.SEARCH_STARTED = undefined;

var _slicedToArray = function () { function sliceIterator(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"]) _i["return"](); } finally { if (_d) throw _e; } } return _arr; } return function (arr, i) { if (Array.isArray(arr)) { return arr; } else if (Symbol.iterator in Object(arr)) { return sliceIterator(arr, i); } else { throw new TypeError("Invalid attempt to destructure non-iterable instance"); } }; }();

var _get = require('lodash/get');

var _get2 = _interopRequireDefault(_get);

var _reducers = require('../reducers');

var _cspace = require('./cspace');

var _cspace2 = _interopRequireDefault(_cspace);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var SEARCH_STARTED = exports.SEARCH_STARTED = 'SEARCH_STARTED';
var SEARCH_FULFILLED = exports.SEARCH_FULFILLED = 'SEARCH_FULFILLED';
var SEARCH_REJECTED = exports.SEARCH_REJECTED = 'SEARCH_REJECTED';

var ERR_NO_RECORD_SERVICE = exports.ERR_NO_RECORD_SERVICE = 'ERR_NO_RECORD_SERVICE';
var ERR_NO_VOCABULARY_SERVICE = exports.ERR_NO_VOCABULARY_SERVICE = 'ERR_NO_VOCABULARY_SERVICE';
var ERR_INVALID_SORT = exports.ERR_INVALID_SORT = 'ERR_INVALID_SORT';

var findColumnByName = function findColumnByName(columns, columnName) {
  if (!columns) return null;

  for (var i = 0; i < columns.length; i += 1) {
    var column = columns[i];

    if (column.name === columnName) {
      return column;
    }
  }

  return null;
};

var getSortParam = function getSortParam(config, searchDescriptor) {
  var sortSpec = searchDescriptor.searchQuery.sort;

  var _sortSpec$split = sortSpec.split(' '),
      _sortSpec$split2 = _slicedToArray(_sortSpec$split, 2),
      sortColumnName = _sortSpec$split2[0],
      sortDir = _sortSpec$split2[1];

  if (sortDir && sortDir !== 'desc') {
    return null;
  }

  var columns = (0, _get2.default)(config, ['recordTypes', searchDescriptor.recordType, 'columns', 'search']);
  var column = findColumnByName(columns, sortColumnName);

  if (column && column.sortBy) {
    return column.sortBy + (sortDir ? ' DESC' : '');
  }

  return null;
};

var search = exports.search = function search(config, searchDescriptor) {
  return function (dispatch, getState) {
    var recordType = searchDescriptor.recordType,
        vocabulary = searchDescriptor.vocabulary,
        searchQuery = searchDescriptor.searchQuery;


    if ((0, _reducers.isSearchPending)(getState(), searchDescriptor) || (0, _reducers.getSearchResult)(getState(), searchDescriptor)) {
      // This search is pending, or already completed without error. Do nothing.

      return null;
    }

    dispatch({
      type: SEARCH_STARTED,
      meta: searchDescriptor
    });

    var recordTypeConfig = config.recordTypes[recordType];

    if (!recordTypeConfig) {
      return dispatch({
        type: SEARCH_REJECTED,
        payload: {
          code: ERR_NO_RECORD_SERVICE
        },
        meta: searchDescriptor
      });
    }

    var recordTypeServicePath = (0, _get2.default)(recordTypeConfig, ['serviceConfig', 'servicePath']);

    if (!recordTypeServicePath) {
      return dispatch({
        type: SEARCH_REJECTED,
        payload: {
          code: ERR_NO_RECORD_SERVICE
        },
        meta: searchDescriptor
      });
    }

    var vocabularyServicePath = vocabulary ? (0, _get2.default)(recordTypeConfig, ['vocabularies', vocabulary, 'serviceConfig', 'servicePath']) : null;

    if (vocabulary && !vocabularyServicePath) {
      return dispatch({
        type: SEARCH_REJECTED,
        payload: {
          code: ERR_NO_VOCABULARY_SERVICE
        },
        meta: searchDescriptor
      });
    }

    var requestConfig = {
      params: {
        kw: searchQuery.kw,
        pgNum: searchQuery.p,
        pgSz: searchQuery.size,
        wf_deleted: false
      }
    };

    if (searchQuery.sort) {
      var sortParam = getSortParam(config, searchDescriptor);

      if (!sortParam) {
        return dispatch({
          type: SEARCH_REJECTED,
          payload: {
            code: ERR_INVALID_SORT
          },
          meta: searchDescriptor
        });
      }

      requestConfig.params.sortBy = sortParam;
    }

    var vocabularyItemsPath = vocabularyServicePath ? '/' + vocabularyServicePath + '/items' : '';
    var path = '' + recordTypeServicePath + vocabularyItemsPath;

    return (0, _cspace2.default)().read(path, requestConfig)
    // Insert an artificial delay for testing.
    // .then(response => {
    //   return new Promise((resolve) => {
    //     window.setTimeout(() => {
    //       resolve(response);
    //     }, 2000);
    //   });
    // })
    .then(function (response) {
      return dispatch({
        type: SEARCH_FULFILLED,
        payload: response,
        meta: searchDescriptor
      });
    }, function (error) {
      return dispatch({
        type: SEARCH_REJECTED,
        payload: error,
        meta: searchDescriptor
      });
    });
  };
};