'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _immutable = require('immutable');

var _immutable2 = _interopRequireDefault(_immutable);

var _reactIntl = require('react-intl');

var _cspaceInput = require('cspace-input');

var _recordDataHelpers = require('../../helpers/recordDataHelpers');

var _RecordEditor = require('../../../styles/cspace-ui/RecordEditor.css');

var _RecordEditor2 = _interopRequireDefault(_RecordEditor);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var Label = _cspaceInput.components.Label;


function getMessage(Wrapper, component, messageDescriptors) {
  var _component$props = component.props,
      msgkey = _component$props.msgkey,
      name = _component$props.name;


  var key = msgkey || name;
  var messageDescriptor = messageDescriptors[key];

  if (!messageDescriptor) {
    return null;
  }

  return _react2.default.createElement(
    Wrapper,
    null,
    _react2.default.createElement(_reactIntl.FormattedMessage, messageDescriptor)
  );
}

function renderTemplate(component, messageDescriptors, handlers) {
  var overrideProps = {};
  var type = component.type;

  if (type) {
    (function () {
      var propTypes = type.propTypes;

      if (propTypes) {
        if (propTypes.name) {
          if (propTypes.label && !component.props.label) {
            overrideProps.label = getMessage(Label, component, messageDescriptors);
          }

          if (propTypes.header && !component.props.header) {
            overrideProps.header = getMessage('h3', component, messageDescriptors);
          }
        }

        Object.keys(handlers).forEach(function (handlerName) {
          if (propTypes[handlerName] && !component.props[handlerName]) {
            overrideProps[handlerName] = handlers[handlerName];
          }
        });
      }
    })();
  }

  return _react2.default.cloneElement(component, overrideProps, _react2.default.Children.map(component.props.children, function (child) {
    return renderTemplate(child, messageDescriptors, handlers);
  }));
}

var RecordEditor = function (_Component) {
  _inherits(RecordEditor, _Component);

  function RecordEditor() {
    _classCallCheck(this, RecordEditor);

    return _possibleConstructorReturn(this, (RecordEditor.__proto__ || Object.getPrototypeOf(RecordEditor)).apply(this, arguments));
  }

  _createClass(RecordEditor, [{
    key: 'getChildContext',
    value: function getChildContext() {
      return {
        recordType: this.props.recordType
      };
    }
  }, {
    key: 'render',
    value: function render() {
      var _props = this.props,
          data = _props.data,
          recordType = _props.recordType,
          generateID = _props.generateID,
          onAddInstance = _props.onAddInstance,
          onCommit = _props.onCommit,
          onMoveInstance = _props.onMoveInstance,
          onRemoveInstance = _props.onRemoveInstance;
      var config = this.context.config;


      var recordTypeConfig = config.recordTypes[recordType];

      var forms = recordTypeConfig.forms,
          messageDescriptors = recordTypeConfig.messageDescriptors;


      var handlers = {
        generateID: generateID,
        onAddInstance: onAddInstance,
        onCommit: onCommit,
        onMoveInstance: onMoveInstance,
        onRemoveInstance: onRemoveInstance
      };

      var formTemplate = forms.default;

      var formContent = _react2.default.cloneElement(formTemplate, {
        name: _recordDataHelpers.DOCUMENT_PROPERTY_NAME,
        value: data.get(_recordDataHelpers.DOCUMENT_PROPERTY_NAME),
        children: _react2.default.Children.map(formTemplate.props.children, function (child) {
          return renderTemplate(child, messageDescriptors, handlers);
        })
      });

      return _react2.default.createElement(
        'form',
        {
          autoComplete: 'off',
          className: _RecordEditor2.default.common
        },
        formContent
      );
    }
  }]);

  return RecordEditor;
}(_react.Component);

exports.default = RecordEditor;


RecordEditor.propTypes = {
  recordType: _react.PropTypes.string.isRequired,
  data: _react.PropTypes.instanceOf(_immutable2.default.Map),
  generateID: _react.PropTypes.func,
  onAddInstance: _react.PropTypes.func,
  onCommit: _react.PropTypes.func,
  onMoveInstance: _react.PropTypes.func,
  onRemoveInstance: _react.PropTypes.func
};

RecordEditor.defaultProps = {
  data: _immutable2.default.Map()
};

RecordEditor.childContextTypes = {
  recordType: _react.PropTypes.string
};

RecordEditor.contextTypes = {
  config: _react.PropTypes.object
};