'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getRecordTypeByServiceObjectName = exports.normalizeConfig = exports.initConfig = exports.mergeConfig = exports.applyPlugins = exports.applyPlugin = exports.evaluatePlugin = undefined;

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

var _merge = require('lodash/merge');

var _merge2 = _interopRequireDefault(_merge);

var _warning = require('warning');

var _warning2 = _interopRequireDefault(_warning);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var evaluatePlugin = exports.evaluatePlugin = function evaluatePlugin(plugin, pluginContext) {
  var pluginType = typeof plugin === 'undefined' ? 'undefined' : _typeof(plugin);

  var isValidType = plugin && (pluginType === 'function' || pluginType === 'object' && !Array.isArray(plugin));

  process.env.NODE_ENV !== 'production' ? (0, _warning2.default)(isValidType, 'A plugin must be an object or a function.') : void 0;

  if (!isValidType) {
    return {};
  }

  return pluginType === 'object' ? plugin : plugin(pluginContext);
};

var applyPlugin = exports.applyPlugin = function applyPlugin(targetConfig, plugin, pluginContext) {
  var pluginConfigContribution = evaluatePlugin(plugin, pluginContext);

  /* eslint-disable no-use-before-define */ // Gotta do this mutual recursion
  return mergeConfig(targetConfig, pluginConfigContribution, pluginContext);
  /* eslint-enable no-use-before-define */
};

var applyPlugins = exports.applyPlugins = function applyPlugins(targetConfig, plugins, pluginContext) {
  var isArray = Array.isArray(plugins);

  process.env.NODE_ENV !== 'production' ? (0, _warning2.default)(isArray, 'Plugins must be an array.') : void 0;

  if (!isArray) {
    return targetConfig;
  }

  return plugins.reduce(function (updatedConfig, plugin) {
    return applyPlugin(updatedConfig, plugin, pluginContext);
  }, targetConfig);
};

var mergeConfig = exports.mergeConfig = function mergeConfig(targetConfig, sourceConfig, pluginContext) {
  var pluginsAppliedConfig = sourceConfig && 'plugins' in sourceConfig ? applyPlugins(targetConfig, sourceConfig.plugins, pluginContext) : targetConfig;

  var mergedConfig = (0, _merge2.default)({}, pluginsAppliedConfig, sourceConfig);

  delete mergedConfig.plugins;

  return mergedConfig;
};

var initConfig = exports.initConfig = function initConfig(config, pluginContext) {
  return mergeConfig({}, config, pluginContext);
};

/*
 * Normalize a configuration object. This function mutates the argument configuration.
 * - Set the name property of each recordTypes entry to its key
 * - Set the name property of each vocabularies entry to its key
 */
var normalizeConfig = exports.normalizeConfig = function normalizeConfig(config) {
  var recordTypes = config.recordTypes;

  Object.keys(recordTypes).forEach(function (recordTypeName) {
    var recordType = recordTypes[recordTypeName];
    var vocabularies = recordType.vocabularies;

    recordType.name = recordTypeName;

    if (vocabularies) {
      Object.keys(vocabularies).forEach(function (vocabularyName) {
        vocabularies[vocabularyName].name = vocabularyName;
      });
    }
  });

  return config;
};

var getRecordTypeByServiceObjectName = exports.getRecordTypeByServiceObjectName = function getRecordTypeByServiceObjectName(config, objectName) {
  if (!config.recordTypesByServiceObjectName) {
    (function () {
      var recordTypesByServiceObjectName = {};

      var recordTypes = config.recordTypes;


      Object.keys(recordTypes).forEach(function (recordTypeName) {
        var recordType = recordTypes[recordTypeName];
        var serviceObjectName = recordType.serviceConfig.objectName;

        recordTypesByServiceObjectName[serviceObjectName] = recordType;
      });

      /* eslint-disable no-param-reassign */
      config.recordTypesByServiceObjectName = recordTypesByServiceObjectName;
      /* eslint-enable no-param-reassign */
    })();
  }

  return config.recordTypesByServiceObjectName[objectName];
};