'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _reactIntl = require('react-intl');

var _cspaceRefname = require('cspace-refname');

var _configHelpers = require('../../../helpers/configHelpers');

var _dateHelpers = require('../../../helpers/dateHelpers');

var formatServiceObjectName = function formatServiceObjectName(value, intl, config) {
  var recordType = (0, _configHelpers.getRecordTypeByServiceObjectName)(config, value);

  if (recordType) {
    return intl.formatMessage(recordType.messageDescriptors.recordNameTitle);
  }

  return '[ ' + value.toLowerCase() + ' ]';
};

exports.default = {
  search: [{
    name: 'docNumber',
    messages: (0, _reactIntl.defineMessages)({
      label: {
        'id': 'column.all.docNumber',
        'defaultMessage': 'Record'
      }
    }),
    // The value -might- be a refname.
    // FIXME: It could also be an option list value. How to tell?
    formatValue: function formatValue(value) {
      return (0, _cspaceRefname.getDisplayName)(value) || value;
    },
    width: 200
  }, {
    name: 'docName',
    messages: (0, _reactIntl.defineMessages)({
      label: {
        'id': 'column.all.docName',
        'defaultMessage': 'Summary'
      }
    }),
    // The value -might- be a refname.
    // FIXME: It could also be an option list value. How to tell?
    formatValue: function formatValue(value) {
      return (0, _cspaceRefname.getDisplayName)(value) || value;
    },
    width: 300
  }, {
    name: 'docType',
    messages: (0, _reactIntl.defineMessages)({
      label: {
        'id': 'column.all.docType',
        'defaultMessage': 'Type'
      }
    }),
    formatValue: function formatValue(value, _ref) {
      var intl = _ref.intl,
          config = _ref.config;
      return formatServiceObjectName(value, intl, config);
    },
    width: 150
  }, {
    name: 'updatedAt',
    messages: (0, _reactIntl.defineMessages)({
      label: {
        'id': 'column.all.updatedAt',
        'defaultMessage': 'Last modified'
      }
    }),
    formatValue: _dateHelpers.formatLocalDateTime,
    sortBy: 'collectionspace_core:updatedAt',
    width: 150
  }]
};