'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getNew = exports.get = undefined;

var _immutable = require('immutable');

var _immutable2 = _interopRequireDefault(_immutable);

var _recordDataHelpers = require('../../helpers/recordDataHelpers');

var _record = require('../../actions/record');

var _idGenerator = require('../../actions/idGenerator');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var addFieldInstance = function addFieldInstance(state, action) {
  var _action$meta = action.meta,
      csid = _action$meta.csid,
      path = _action$meta.path;


  var data = state[csid];

  if (!data) {
    return state;
  }

  var value = (0, _recordDataHelpers.deepGet)(data, path);
  var list = _immutable2.default.List.isList(value) ? value : _immutable2.default.List.of(value);

  var updatedData = (0, _recordDataHelpers.deepSet)(data, path, list.push(undefined));

  return Object.assign({}, state, _defineProperty({}, csid, updatedData));
};

var createNewRecord = function createNewRecord(state, action) {
  var recordTypeConfig = action.meta.recordTypeConfig;

  // TODO: Implement cloning an existing record.

  // This code assumes that only one new record of any type may be in the process of being
  // edited at any time. The new record's data is stored alongside existing record data, at
  // key ''.

  return Object.assign({}, state, {
    '': (0, _recordDataHelpers.createRecordData)(recordTypeConfig)
  });
};

var deleteFieldValue = function deleteFieldValue(state, action) {
  var _action$meta2 = action.meta,
      csid = _action$meta2.csid,
      path = _action$meta2.path;


  var data = state[csid];

  if (!data) {
    return state;
  }

  var updatedData = data.deleteIn(path);

  return Object.assign({}, state, _defineProperty({}, csid, updatedData));
};

var moveFieldValue = function moveFieldValue(state, action) {
  var _action$meta3 = action.meta,
      csid = _action$meta3.csid,
      path = _action$meta3.path,
      newPosition = _action$meta3.newPosition;


  var data = state[csid];

  if (!data) {
    return state;
  }

  var listPath = path.slice(0, -1);
  var oldPosition = path[path.length - 1];

  var list = (0, _recordDataHelpers.deepGet)(data, listPath);

  if (!_immutable2.default.List.isList(list)) {
    return state;
  }

  var value = list.get(oldPosition);

  list = list.delete(oldPosition);
  list = list.insert(newPosition, value);

  var updatedData = (0, _recordDataHelpers.deepSet)(data, listPath, list);

  return Object.assign({}, state, _defineProperty({}, csid, updatedData));
};

var setFieldValue = function setFieldValue(state, action) {
  var _action$meta4 = action.meta,
      csid = _action$meta4.csid,
      path = _action$meta4.path;


  var data = state[csid];

  if (!data) {
    return state;
  }

  var newValue = action.payload;
  var updatedData = (0, _recordDataHelpers.deepSet)(data, path, newValue);

  return Object.assign({}, state, _defineProperty({}, csid, updatedData));
};

var handleRecordReadFulfilled = function handleRecordReadFulfilled(state, action) {
  return Object.assign({}, state, _defineProperty({}, action.meta.csid, _immutable2.default.fromJS(action.payload.data)));
};

var handleRecordSaveFulfilled = function handleRecordSaveFulfilled(state, action) {
  var response = action.payload;
  var csid = action.meta.csid;

  if (response.status === 201 && response.headers.location) {
    // A new record was created. There won't be any data in the response. Copy the data in the
    // slot for the empty csid to the data slot for the new record. This prevents the form data
    // from blinking out when the browser is directed to the new csid, as it would otherwise find
    // no data until the read call to the REST API completed.

    var location = response.headers.location;
    var newRecordCsid = location.substring(location.lastIndexOf('/') + 1);

    return Object.assign({}, state, _defineProperty({}, newRecordCsid, state['']));
  }

  return Object.assign({}, state, _defineProperty({}, csid, _immutable2.default.fromJS(response.data)));
};

var handleCreateIDFulfilled = function handleCreateIDFulfilled(state, action) {
  var _action$meta5 = action.meta,
      csid = _action$meta5.csid,
      path = _action$meta5.path;


  var data = state[csid];

  if (!data) {
    return state;
  }

  var newValue = action.payload.data;
  var updatedData = (0, _recordDataHelpers.deepSet)(data, path, newValue);

  return Object.assign({}, state, _defineProperty({}, csid, updatedData));
};

exports.default = function () {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var action = arguments[1];

  switch (action.type) {
    case _record.ADD_FIELD_INSTANCE:
      return addFieldInstance(state, action);
    case _record.CREATE_NEW_RECORD:
      return createNewRecord(state, action);
    case _record.DELETE_FIELD_VALUE:
      return deleteFieldValue(state, action);
    case _record.MOVE_FIELD_VALUE:
      return moveFieldValue(state, action);
    case _record.SET_FIELD_VALUE:
      return setFieldValue(state, action);
    case _record.RECORD_READ_FULFILLED:
      return handleRecordReadFulfilled(state, action);
    case _record.RECORD_SAVE_FULFILLED:
      return handleRecordSaveFulfilled(state, action);
    case _idGenerator.CREATE_ID_FULFILLED:
      return handleCreateIDFulfilled(state, action);
    default:
      return state;
  }
};

var get = exports.get = function get(state, csid) {
  return state[csid];
};

var getNew = exports.getNew = function getNew(state) {
  return get(state, '');
};